# Flytekit Vaex Plugin
[Vaex](https://github.com/vaexio/vaex) is a high-performance Python library for lazy out-of-core DataFrames
(similar to Pandas) to visualize and explore big tabular datasets.

This plugin supports `vaex.DataFrame` as a data type with [StructuredDataset](https://docs.flyte.org/projects/cookbook/en/latest/auto/core/type_system/structured_dataset.html).

To install the plugin, run the following command:

```bash
pip install flytekitplugins-vaex
```
